transform — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# transform

Structure.transform(transformation_matrix=array([[1, 0, 0], [0, 1, 0], [0, 0, 1]]))

  Transform the crystla lattice by a transformation matrix

  Parameters:

    transformation_matrix (np.ndarray, optional) – The transformation matrix, by default np.array([[1, 0, 0], [0, 1, 0], [0, 0, 1]])

  Returns:

    pyprocar.core.Structure – The transformed structure

  Raises:

    ValueError – Raise error if the transform is not proper